==> bibledit-3.4.tar.gz: bibledit-3.4/src/ot-nt-parallels.h <==
/*
** Copyright (©) 2003-2008 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**  
*/


#ifndef INCLUDED_OT_NT_PARALLELS_H
#define INCLUDED_OT_NT_PARALLELS_H


#include "libraries.h"
#include "reference.h"


class OtNtParallelSet
{
public:
  OtNtParallelSet (int dummy);
  vector <Reference> references;
private:
};


class OtNtParallelSection
{
public:
  OtNtParallelSection (int dummy);
  ustring title;
  vector <OtNtParallelSet> sets;
private:
};


class OtNtParallels
{
public:
  OtNtParallels (int dummy);
  void get (Reference& reference, vector <Reference>& references, vector <ustring>& comments);
  void readot ();
  void readnt ();
  vector <OtNtParallelSection> sections;
private:
  void read (gchar * filename);
};


class OtNtParallelDataSet
{
public:
  OtNtParallelDataSet (int dummy);
  vector <ustring> data;
private:
};


class OtNtParallelDataSection
{
public:
  OtNtParallelDataSection (int dummy);
  ustring title;
  vector <OtNtParallelDataSet> sets;
private:
};



#endif

==> bibledit_3.8.orig.tar.gz: bibledit-3.8/src/ot-nt-parallels.h <==
/*
** Copyright (©) 2003-2009 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**  
*/


#ifndef INCLUDED_OT_NT_PARALLELS_H
#define INCLUDED_OT_NT_PARALLELS_H


#include "libraries.h"
#include "reference.h"


class OtNtParallelSet
{
public:
  OtNtParallelSet (int dummy);
  vector <Reference> references;
private:
};


class OtNtParallelSection
{
public:
  OtNtParallelSection (int dummy);
  ustring title;
  vector <OtNtParallelSet> sets;
private:
};


class OtNtParallels
{
public:
  OtNtParallels (int dummy);
  void get (Reference& reference, vector <Reference>& references, vector <ustring>& comments);
  void readot ();
  void readnt ();
  vector <OtNtParallelSection> sections;
private:
  void read (const gchar * filename);
};


class OtNtParallelDataSet
{
public:
  OtNtParallelDataSet (int dummy);
  vector <ustring> data;
private:
};


class OtNtParallelDataSection
{
public:
  OtNtParallelDataSection (int dummy);
  ustring title;
  vector <OtNtParallelDataSet> sets;
private:
};



#endif
